# LegacyWafUpdateStatus


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**completed_at** | **str** | Date and time that job was completed. | [optional] 
**created_at** | **str** | Date and time that job was created. | [optional] 
**data** | **str** | This field can contain data passed to the background worker as well as output from the background job. | [optional] 
**message** | **str** | Message with information about the status of the update. | [optional] 
**status** | **str** | Current status of the update. | [optional] 
**updated_at** | **str** | Date and time that job was last updated. | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


